@@ -12,7 +12,7 @@ use base qw(Net::DNS::Resolver::Base DynaLoader), OS_CONF;
 our $VERSION;
 
 BEGIN {
-	$VERSION = '1.27_02';
+	$VERSION = '1.27_03';
 	eval { __PACKAGE__->bootstrap($VERSION) };
 }
 
@@ -25,7 +25,6 @@ use constant UB_VERSION => scalar eval {
 use constant UB_CONTEXT => 'Net::DNS::Resolver::Unbound::Context';
 
 use constant IP_PREF	 => UB_VERSION > 11100;
-use constant ASYNC	 => UB_CONTEXT->can('async');
 use constant ADD_TA_AUTR => UB_CONTEXT->can('add_ta_autr');
 use constant SET_STUB	 => UB_CONTEXT->can('set_stub');
 use constant SET_TLS	 => UB_CONTEXT->can('set_tls');
@@ -434,7 +433,7 @@ If false (by default), a process is forked to perform the work.
 
 sub async_thread {
 	my ( $self, $threaded ) = @_;
-	return ASYNC ? $self->_config( 'async', $threaded ) : undef;
+	return $self->_config( 'async', $threaded );
 }
 
 
@@ -513,7 +512,7 @@ sub _config {
 	my ( $self, $name, @arg ) = @_;
 	my $entry = ( scalar(@arg) == 1 ) ? $arg[0] : [@arg];
 	my $ctx	  = $self->{test_ctx};
-	$ctx = $self->{test_ctx} = Net::DNS::Resolver::Unbound::Context->new() unless $ctx;
+	$self->{test_ctx} = $ctx = Net::DNS::Resolver::Unbound::Context->new() unless $ctx;
 	$ctx->$name(@arg) if @arg;				# error check only
 	my $state = $self->{update}->{$name};
 	if ( defined $state ) {					# second and subsequent entries
@@ -531,7 +530,7 @@ sub _option {
 	my ($entry) = @arg;
 	my $opt	    = "${name}:";
 	my $ctx	    = $self->{test_ctx};
-	$ctx = $self->{test_ctx} = Net::DNS::Resolver::Unbound::Context->new() unless $ctx;
+	$self->{test_ctx} = $ctx = Net::DNS::Resolver::Unbound::Context->new() unless $ctx;
 	$ctx->set_option( $opt, @arg ) if defined $entry;	# error check only
 	my $updopt = $self->{update}->{set_option};
 	my %option = map {$_} @$updopt;
@@ -572,9 +571,8 @@ sub _finalise_config {
 
 	my $update = delete $self->{update};
 	return unless $update;
-
 	delete $self->{test_ctx};
-	my $ctx = $self->{ub_ctx} = Net::DNS::Resolver::Unbound::Context->new();
+	delete $self->{ub_ctx};
 
 	my $config = $self->{config};
 	my $cfgopt = delete $config->{set_option};		# extract option lists
@@ -590,6 +588,7 @@ sub _finalise_config {
 	}
 	my @option = map { ( $_, $option{$_} ) } sort keys %option;    # rebuild option list
 
+	my $ctx = $self->{ub_ctx} = Net::DNS::Resolver::Unbound::Context->new();
 	foreach my $name ( keys %option ) {			# set unbound options
 		foreach my $value ( map { ref($_) ? @$_ : $_ } $option{$name} ) {
 			$ctx->set_option( $name, $value );
